<?php
//
//	Module name      :	testodbc.php
//
//	Description      :	Test file for odbc module
//
//	Parameters       :	None
//	Notes - usage    :	None
//


//--- Include files --------------------------------------------------------------------------------



require_once("debug.php");
require_once("odbc.php");
require_once("dblog.php");



//--- Global constants -----------------------------------------------------------------------------



define("PAGE_TIMER_NAME", "TestPage");
define("TEST_TIMER_NAME", "TestFunc");



//--- Global variables -----------------------------------------------------------------------------



$Module_prefix = "ODBC";



//--- Functions code -------------------------------------------------------------------------------



function PrintFooter()
// Prints the test page footer.
{
	print "
		<!--- Start of PrintFooter ------------------------------------------------------>
		</body>
		</html>";
	$sec = DMtimerRead(PAGE_TIMER_NAME);
	print "
		<!--- End of PrintFooter -------------------------------------------------------->
		<!--- (Elapsed seconds for page construction: $sec) ------------------------->
		";
}



function PrintHeader($browser_title)
// Prints the test page header.
{
	DMtimerReset(PAGE_TIMER_NAME);
	$now = gmdate('D, d M Y H:i:s') . ' GMT';
	header('Expires: ' . $now);						// rfc2616 - Section 14.21
	header('Last-Modified: ' . $now);
	header('Cache-Control: no-store, no-cache, must-revalidate, pre-check=0, post-check=0, max-age=0'); // HTTP/1.1
	header('Pragma: no-cache'); // HTTP/1.0
	print "
		<!--- Start of PrintHeader ------------------------------------------------------>
		<html>
		<head>
			<title>$browser_title</title>
			<meta http-equiv='content-type' content='text/html; charset=iso-8859-1'>
		</head>
		<body>
		<!--- End of PrintHeader -------------------------------------------------------->
		";
}



function Test()
// Calls DPrint for each parameter passed; if ErrorMsg and Result are defined in the tested module,
// calls them and shows their values after the last parameter evaluation. Returns the value of the last
// parameter evaluation.
{
	global $Module_prefix;
	static $first_call = TRUE;

	$em_name = "${Module_prefix}ErrorMsg";
	$em = function_exists($em_name);
	$r_name = "${Module_prefix}Result";
	$r = function_exists($r_name);
	for ($i = 0; $i < func_num_args(); $i++)
		$result = DPrint(func_get_arg($i));
	if ($first_call)
	{
		$first_call = FALSE;
		$msec = 0;
	}
	else
		$msec = DMtimerRead(TEST_TIMER_NAME);
	DMTimerReset(TEST_TIMER_NAME);
	print "
		<table border=1 cellspacing=1 cellpadding=3 width=100%>
		<tr valign=top>
			<td width=1%>
				<center><font style='visibility:hidden'><b>DPrint</b></font></center>
			</td>
			<td><font size=-1>
				" . ($r ? "<b>${Module_prefix}Result:</b> '" . call_user_func($r_name) . "';" : "") . "
				" . ($em ? "<b>${Module_prefix}ErrorMsg:</b> '" . call_user_func($em_name) . "';" : "") . "
				<b>Elapsed secs from last call:</b> $msec</font>
			</td>
		</tr></table><br>
		";
	return $result;
}



//--- Main code ------------------------------------------------------------------------------------



	DSetDebugWindow(D_WIN_DEF_X, D_WIN_DEF_Y, D_WIN_DEF_WIDTH, D_WIN_DEF_HEIGHT, FALSE);
	PrintHeader("Test file for " . constant("${Module_prefix}_MODULE_NAME"));
	Test("Initial internal status");

	// Test code for odbc.php starts here.

	$ODBC_db_log = TRUE;
	DPrint("DbLog module init", DLInit("statistichelog", "log", ""), DLResult(), DLErrorMsg());

	DPrint("ODBCExtErrorMsg test", ODBCExtErrorMsg());

	$My_db = array();
	Test(ODBCInit($My_db), ODBCExtErrorMsg());
	$My_db = array("Dsn" => "DbInesistente", "User" => "log", "Pwd" => "");
	Test(ODBCInit($My_db), ODBCExtErrorMsg());
	$My_db = array("Dsn" => "statistichelog", "User" => "log", "Pwd" => "pwd_errata");
	Test(ODBCInit($My_db), ODBCExtErrorMsg());
	$My_db = array("Dsn" => "statistichelog", "User" => "log", "Pwd" => "");
	Test(ODBCInit($My_db), ODBCExtErrorMsg());

	$False_db = array("Dsn" => "DbNonAperto", "User" => "log", "Pwd" => "");
	Test(ODBCQuery($False_db, "INSERT INTO InternalError VALUES (0)"), ODBCExtErrorMsg());
	Test(ODBCQuery($My_db, "INSERT INTO TabellaInesistente VALUES (0)"), ODBCExtErrorMsg());
	Test(ODBCQuery($My_db,
			"INSERT INTO InternalError (Ts, Ip, ErrorCode, Url, ParametroDiTroppo) VALUES (0, 0, 0, 0, 0)"),
			ODBCExtErrorMsg());
	Test(ODBCQuery($My_db, "INSERT INTO InternalError (Ts, Ip, ErrorCode, Url) VALUES (0, 0, 0, 0)"),
			ODBCExtErrorMsg());
	DPrint("AffectedRows", ODBCAffectedRows($My_db));
	DPrint("AffectedRows", ODBCAffectedRows($False_db));
	Test(ODBCQuery($My_db, "INSERT INTO InternalError (Ts) SELECT Ts FROM ODBC WHERE Ts < 0"),
			ODBCExtErrorMsg());
	DPrint("AffectedRows", ODBCAffectedRows($My_db));
	
	Test(ODBCSelect($My_db, "SELECT * FROM InternalError", 99), ODBCExtErrorMsg());
	Test(ODBCSelect($False_db, "SELECT * FROM InternalError", ODBC_FIRST), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT * FROM TabellaInesistente", ODBC_FIRST), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT COUNT(*) FROM InternalError WHERE Ts < 0", ODBC_FIRST),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT * FROM InternalError WHERE Ts < 0", ODBC_FIRST),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT COUNT(*) FROM InternalError", ODBC_FIRST),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT * FROM InternalError", ODBC_FIRST),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_NEXT),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_CLOSE), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_CLOSE), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_NEXT), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT COUNT(*) FROM ODBC WHERE Dsn = 'DbNonAperto'", ODBC_FIRST),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT * FROM ODBC WHERE Dsn = 'DbNonAperto'", ODBC_FIRST),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_NEXT),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_NEXT),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_CLOSE), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_CLOSE), ODBCExtErrorMsg());
	
	Test(ODBCSelectManyRows($False_db, "SELECT * FROM InternalError"), ODBCExtErrorMsg());
	Test(ODBCSelectManyRows($My_db, "SELECT * FROM TabellaInesistente"), ODBCExtErrorMsg());
	Test(ODBCSelectManyRows($My_db, "SELECT * FROM InternalError WHERE Ts < 0"),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectManyRows($My_db, "SELECT * FROM InternalError"),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectManyRows($My_db, "SELECT * FROM ODBC WHERE Dsn = 'DbNonAperto'"),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	
	Test(ODBCSelectOneRow($False_db, "SELECT * FROM InternalError"), ODBCExtErrorMsg());
	Test(ODBCSelectOneRow($My_db, "SELECT * FROM TabellaInesistente"), ODBCExtErrorMsg());
	Test(ODBCSelectOneRow($My_db, "SELECT * FROM InternalError WHERE Ts < 0"),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectOneRow($My_db, "SELECT * FROM InternalError"),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectOneRow($My_db, "SELECT * FROM ODBC WHERE Dsn = 'DbNonAperto'"),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());

	Test(ODBCSelect($My_db, "SELECT COUNT(*) FROM InternalError WHERE Ts < 0", ODBC_FIRST, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT * FROM InternalError WHERE Ts < 0", ODBC_FIRST, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT COUNT(*) FROM InternalError", ODBC_FIRST, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT * FROM InternalError", ODBC_FIRST, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_NEXT, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_CLOSE), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT COUNT(*) FROM ODBC WHERE Dsn = 'DbNonAperto'", ODBC_FIRST, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT * FROM ODBC WHERE Dsn = 'DbNonAperto'", ODBC_FIRST, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_NEXT, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_NEXT, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_NEXT, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_NEXT, ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_CLOSE), ODBCExtErrorMsg());
	Test(ODBCSelectManyRows($My_db, "SELECT * FROM InternalError WHERE Ts < 0", ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectManyRows($My_db, "SELECT * FROM InternalError", ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectManyRows($My_db, "SELECT * FROM ODBC WHERE Dsn = 'DbNonAperto'", ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectOneRow($My_db, "SELECT * FROM InternalError WHERE Ts < 0", ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectOneRow($My_db, "SELECT * FROM InternalError", ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectOneRow($My_db, "SELECT * FROM ODBC WHERE Dsn = 'DbNonAperto'", ODBC_ASS),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());

	Test(ODBCSelect($My_db, "SELECT * FROM InternalError", ODBC_FIRST, ODBC_STD),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "SELECT * FROM InternalError", ODBC_FIRST, ODBC_FLAT),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelect($My_db, "", ODBC_CLOSE), ODBCExtErrorMsg());
	Test(ODBCSelectOneRow($My_db, "SELECT * FROM InternalError", ODBC_STD),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectOneRow($My_db, "SELECT * FROM InternalError", ODBC_FLAT),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectManyRows($My_db, "SELECT * FROM InternalError", ODBC_STD),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());
	Test(ODBCSelectManyRows($My_db, "SELECT * FROM InternalError", ODBC_FLAT),
			"AffectedRows", ODBCAffectedRows($My_db), ODBCExtErrorMsg());

	Test(ODBCDone($My_db), ODBCExtErrorMsg());
	Test(ODBCDone($My_db), ODBCExtErrorMsg());

	// Test code for odbc.php ends here.

	Test("Final internal status");
	PrintFooter();	
?>
